summaryrefslogtreecommitdiffhomepage
path: root/examples/csmap_erase.c
diff options
context:
space:
mode:
Diffstat (limited to 'examples/csmap_erase.c')
-rw-r--r--examples/csmap_erase.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/csmap_erase.c b/examples/csmap_erase.c
index 9cf65389..7b179bef 100644
--- a/examples/csmap_erase.c
+++ b/examples/csmap_erase.c
@@ -36,8 +36,8 @@ int main()
c_auto (mymap, m2)
{
- // Fill in some data to test with, one at a time, using c_apply_pair()
- c_apply_pair(mymap, emplace, &m2, {
+ // Fill in some data to test with, one at a time, using c_apply()
+ c_apply(v, mymap_emplace(&m2, c_pair(v)), mymap_rawvalue, {
{10, "Bob"},
{11, "Rob"},
{12, "Robert"},